@@ -4,6 +4,7 @@
 About::About(QWidget *parent) :
     QDialog(parent),
     ui(new Ui::About)
+
 {
     ui->setupUi(this);
 
@@ -11,11 +12,17 @@ About::About(QWidget *parent) :
     QFont f = ui->text1->font();
     f.setPointSize( f.pointSize() + 5 );
     f.setBold(true);
+    QFont g = ui->text1->font();
+    g.setPointSize( g.pointSize() - 1);
+
+
+    //Set Font Sizes
     ui->bander->setFont(f);
-    ui->bander->setText("bander 0.0.3");
+    ui->text2->setFont(g);
+
+    ui->bander->setText("bander 0.0.4");
     ui->text1->setText(tr("Electronic Components Helper"));
     ui->text2->setText("(C) 2013-2014 sixwheeledbeast & pichlo");
-
 }
 
 About::~About()
